@@ -9,6 +9,7 @@ from Products.CMFPlone import utils as CMFPloneUtils
 from zope.i18nmessageid import MessageFactory
 from zope.i18n import translate
 from DateTime import DateTime
+import datetime
 try:
     import json
 except:
@@ -88,6 +89,7 @@ def getCriteriaItems(context, request):
         criteria = [a for a in listCriteria if a.Field() == selectedCriteria]
     else:
         criteria = listCriteria
+    criteria = [a for a in criteria if a.meta_type in ['ATPortalTypeCriterion', 'ATSelectionCriterion', 'ATListCriterion']]
     if not criteria:
         return False
     criteria = criteria[0]
@@ -126,7 +128,10 @@ def getCookieItems(request, field):
     return False
 
 def getColorIndex(context, request, eventPath=None, brain=None):
+    colorIndex = ' colorIndex-undefined'
     criteriaItems = getCriteriaItems(context, request)
+    if not criteriaItems:
+        return colorIndex
     catalog = getToolByName(context, 'portal_catalog')
     if not brain:
         if not eventPath:
@@ -137,7 +142,6 @@ def getColorIndex(context, request, eventPath=None, brain=None):
         selectedItems = criteriaItems['values']
     if not isinstance(selectedItems, list):
         selectedItems = [selectedItems,]
-    colorIndex = ' colorIndex-undefined'
     if criteriaItems:
         brainVal = getattr(brain, criteriaItems['name'])
         brainVal = isinstance(brainVal, (tuple, list)) and brainVal or [brainVal,]
@@ -183,6 +187,42 @@ class SolgemaFullcalendarJS(BrowserView):
         lang = lang[:2]
         return lang
 
+    def getFirstDay(self):
+        if getattr(self.calendar, 'relativeFirstDay', '') in [None, '']:
+            return self.calendar.firstDay
+        else:
+            now = datetime.datetime.now()
+            delta = datetime.timedelta(hours=int(getattr(self.calendar, 'relativeFirstDay')))
+            newdate = now+delta
+            return newdate.isoweekday()-1
+
+    def getYear(self):
+        if getattr(self.calendar, 'relativeFirstDay', '') in [None, '']:
+            return datetime.datetime.now().year
+        else:
+            now = datetime.datetime.now()
+            delta = datetime.timedelta(hours=int(getattr(self.calendar, 'relativeFirstDay')))
+            newdate = now+delta
+            return int(newdate.year)
+
+    def getMonthNumber(self):
+        if getattr(self.calendar, 'relativeFirstDay', '') in [None, '']:
+            return datetime.datetime.now().month
+        else:
+            now = datetime.datetime.now()
+            delta = datetime.timedelta(hours=int(getattr(self.calendar, 'relativeFirstDay')))
+            newdate = now+delta
+            return int(newdate.month)
+
+    def getDate(self):
+        if getattr(self.calendar, 'relativeFirstDay', '') in [None, '']:
+            return datetime.datetime.now().day
+        else:
+            now = datetime.datetime.now()
+            delta = datetime.timedelta(hours=int(getattr(self.calendar, 'relativeFirstDay')))
+            newdate = now+delta
+            return int(newdate.day)
+
     def getMonthsNames(self):
         return [PLMF(self._ts.month_msgid(m), default=self._ts.month_english(m)) for m in [a+1 for a in range(12)]]
 
@@ -306,7 +346,7 @@ class SolgemaFullcalendarEvents(BrowserView):
             response.expireCookie('sfqueryDisplay')
 
         for criteria in self.context.listCriteria():
-            if criteria.meta_type not in ['ATSelectionCriterion', 'ATListCriterion', 'ATSortCriterion'] and criteria.Field():
+            if criteria.meta_type not in ['ATSelectionCriterion', 'ATListCriterion', 'ATSortCriterion', 'ATPortalTypeCriterion'] and criteria.Field():
                 args[criteria.Field()] = query[criteria.Field()]
             elif criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion']:
                 items = getCookieItems(self.request, criteria.Field())
@@ -320,7 +360,10 @@ class SolgemaFullcalendarEvents(BrowserView):
         args['start'] = {'query': DateTime(self.request.get('end')), 'range':'max'}
         args['end'] = {'query': DateTime(self.request.get('start')), 'range':'min'}
         catalog = getToolByName(context, 'portal_catalog')
+        editargs = args.copy()
+        editargs['SFAllowedRolesAndUsersModify'] = self._listSFAllowedRolesAndUsersModify()
         brains = catalog.searchResults(**args)
+        editpaths = [a.getURL() for a in catalog.searchResults(**editargs)]
         for filt in filters:
             if isinstance(filt['values'], str):
                 brains = [ a for a in brains if not getattr(a, filt['name']) ]
@@ -336,11 +379,10 @@ class SolgemaFullcalendarEvents(BrowserView):
                 editable = True
             else:
                 editable = False
-            if getattr(brain, 'SFAllowedRolesAndUsersModify', None) != None:
-                if len([a for a in self._listSFAllowedRolesAndUsersModify() if a in brain.SFAllowedRolesAndUsersModify])>0:
-                    editable = True
-                else:
-                    editable = False
+            if brain.getURL() in editpaths:
+                editable = True
+            else:
+                editable = False
             if brain.end - brain.start > 1.0:
                 allday = True
             else:
