@@ -158,10 +158,15 @@ class ISolgemaFullcalendarProperties(Interface):
                                   source = "solgemafullcalendar.daysOfWeek",
                                   default = 1 )
 
+    relativeFirstDay = schema.TextLine( title = _(u"label_relativeFirstDay"),
+                                  required = False,
+                                  description = _(u"help_relativeFirstDay"),
+                                  default = u'' )
+
     firstHour = schema.TextLine( title = _(u"label_firstHour"),
                                   required = True,
                                   description = _(u"help_firstHour"),
-                                  default = u'6' )
+                                  default = u'-1' )
 
     minTime = schema.TextLine( title = _(u"label_minTime"),
                                   required = True,
